@@ -5,16 +5,20 @@ from dbsettings.loading import register_setting, unregister_setting
 
 __all__ = ['Group']
 
+
 class GroupBase(type):
-    def __init__(cls, name, bases, attrs):
+    def __init__(mcs, name, bases, attrs):
         if not bases or bases == (object,):
             return
         attrs.pop('__module__', None)
         attrs.pop('__doc__', None)
         for attribute_name, attr in attrs.items():
             if not isinstance(attr, Value):
-                raise TypeError('The type of %s (%s) is not a valid Value.' % (attribute_name, attr.__class__.__name__))
-            cls.add_to_class(attribute_name, attr)
+                raise TypeError('The type of %s (%s) is not a valid Value.' %
+                                (attribute_name, attr.__class__.__name__))
+            mcs.add_to_class(attribute_name, attr)
+        super(GroupBase, mcs).__init__(name, bases, attrs)
+
 
 def install_permission(cls, permission):
     if permission not in cls._meta.permissions:
@@ -25,20 +29,23 @@ def install_permission(cls, permission):
             # Permissions were supplied as a tuple, so preserve that
             cls._meta.permissions = tuple(cls._meta.permissions + (permission,))
 
+
 class GroupDescriptor(object):
     def __init__(self, group, attribute_name):
         self.group = group
         self.attribute_name = attribute_name
 
-    def __get__(self, instance=None, type=None):
-        if instance != None:
-            raise AttributeError, "%r is not accessible from %s instances." % (self.attribute_name, type.__name__)
+    def __get__(self, instance=None, cls=None):
+        if instance is not None:
+            raise AttributeError("%r is not accessible from %s instances." %
+                                 (self.attribute_name, cls.__name__))
         return self.group
 
+
 class Group(object):
     __metaclass__ = GroupBase
 
-    def __new__(cls, copy=True):
+    def __new__(cls, verbose_name=None, copy=True):
         # If not otherwise provided, set the module to where it was executed
         if '__module__' in cls.__dict__:
             module_name = cls.__dict__['__module__']
@@ -50,9 +57,11 @@ class Group(object):
             attrs = [(k, v.copy()) for (k, v) in attrs]
         attrs.sort(lambda a, b: cmp(a[1], b[1]))
 
-        for key, attr in attrs:
+        for _, attr in attrs:
             attr.creation_counter = Value.creation_counter
             Value.creation_counter += 1
+            if not hasattr(attr, 'verbose_name'):
+                attr.verbose_name = verbose_name
             register_setting(attr)
 
         attr_dict = dict(attrs + [('__module__', module_name)])
@@ -62,8 +71,6 @@ class Group(object):
         group = object.__new__(type('Group', (cls,), attr_dict))
         group._settings = attrs
 
-        from django.contrib.auth.models import Permission
-
         return group
 
     def contribute_to_class(self, cls, name):
@@ -91,9 +98,9 @@ class Group(object):
         # Finally, place the attribute on the class
         setattr(cls, name, GroupDescriptor(self, name))
 
+    @classmethod
     def add_to_class(cls, attribute_name, value):
         value.contribute_to_class(cls, attribute_name)
-    add_to_class = classmethod(add_to_class)
 
     def __add__(self, other):
         if not isinstance(other, Group):
@@ -104,11 +111,11 @@ class Group(object):
         return type('Group', (Group,), attrs)(copy=False)
 
     def __iter__(self):
-        for attribute_name, setting in self._settings:
+        for attribute_name, _ in self._settings:
             yield attribute_name, getattr(self, attribute_name)
 
     def keys(self):
-        return [k for (k, v) in self]
+        return [k for (k, _) in self]
 
     def values(self):
-        return [v for (k, v) in self]
+        return [v for (_, v) in self]
