@@ -1,11 +1,13 @@
 from django.db import models
 from django.contrib.sites.models import Site
 
+
 class SettingManager(models.Manager):
     def get_query_set(self):
         all = super(SettingManager, self).get_query_set()
         return all.filter(site=Site.objects.get_current())
 
+
 class Setting(models.Model):
     site = models.ForeignKey(Site)
     module_name = models.CharField(max_length=255)
@@ -16,8 +18,8 @@ class Setting(models.Model):
     objects = SettingManager()
 
     def __nonzero__(self):
-        return self.id is not None
+        return self.pk is not None
 
-    def save(self):
+    def save(self, *args, **kwargs):
         self.site = Site.objects.get_current()
-        return super(Setting, self).save()
\ No newline at end of file
+        return super(Setting, self).save(*args, **kwargs)
