@@ -3,6 +3,7 @@ import datetime
 from django.db import models
 from django import test
 from django.utils.functional import curry
+from django.utils.translation import activate, deactivate
 
 import dbsettings
 from dbsettings import loading, views
@@ -47,7 +48,7 @@ class Blankable(models.Model):
     settings = TestSettings()
 
 class Editable(models.Model):
-    settings = TestSettings()
+    settings = TestSettings('Verbose name')
 
 class Combined(models.Model):
     class settings(dbsettings.Group):
@@ -76,6 +77,15 @@ module_clash2 = ClashSettings2()
 class SettingsTestCase(test.TestCase):
     urls = 'dbsettings.tests.test_urls'
 
+    @classmethod
+    def setUpClass(cls):
+        # Since some text assertions are performed, make sure that no translation interrupts.
+        activate('en')
+
+    @classmethod
+    def tearDownClass(cls):
+        deactivate()
+
     def setUp(self):
         # Standard test fixtures don't update the in-memory cache.
         # So we have to do it ourselves this time.
@@ -298,6 +308,10 @@ class SettingsTestCase(test.TestCase):
         perm = Permission.objects.get(codename='can_edit_editable_settings')
         user.user_permissions.add(perm)
 
+        # Check if verbose_name appears
+        response = self.client.get(site_form)
+        self.assertContains(response, 'Verbose name')
+
         # Erroneous submissions should be caught by newforms
         data = {
             'dbsettings.tests__Editable__integer': '3.5',
@@ -345,4 +359,4 @@ class SettingsTestCase(test.TestCase):
 
         #response = self.client.get(site_form)
         #self.assertTemplateUsed(response, 'dbsettings/site_settings.html')
-        #self.assertEqual(len(response.context[0]['form'].fields), 14)
\ No newline at end of file
+        #self.assertEqual(len(response.context[0]['form'].fields), 14)
