@@ -1,30 +1,27 @@
 import datetime
+from decimal import Decimal
+from hashlib import md5
+from os.path import join as pjoin
 import time
 try:
     from PIL import Image
 except ImportError:
     import Image
-from hashlib import md5
-from os.path import join as pjoin
 
 from django import forms
 from django.conf import settings
-from django.utils.safestring import mark_safe
-from django.utils import formats
 from django.core.files.uploadedfile import SimpleUploadedFile
+from django.utils import formats
+from django.utils.safestring import mark_safe
 
 from dbsettings.loading import get_setting_storage, set_setting_value
 
-try:
-    from decimal import Decimal
-except ImportError:
-    from django.utils._decimal import Decimal
-
 __all__ = ['Value', 'BooleanValue', 'DecimalValue', 'EmailValue',
            'DurationValue', 'FloatValue', 'IntegerValue', 'PercentValue',
            'PositiveIntegerValue', 'StringValue', 'TextValue',
            'MultiSeparatorValue', 'ImageValue',
-           'DateTimeValue', 'DateValue', 'TimeValue',]
+           'DateTimeValue', 'DateValue', 'TimeValue']
+
 
 class Value(object):
 
@@ -36,7 +33,7 @@ class Value(object):
         self.help_text = help_text
         self.choices = choices or []
         self.required = required
-        if default == None:
+        if default is None:
             self.default = self.unitialized_value
         else:
             self.default = default
@@ -49,13 +46,13 @@ class Value(object):
         return cmp(self.creation_counter, other.creation_counter)
 
     def copy(self):
-        new_value = self.__class__(self.description, self.help_text)
+        new_value = self.__class__()
         new_value.__dict__ = self.__dict__.copy()
         return new_value
 
+    @property
     def key(self):
         return self.module_name, self.class_name, self.attribute_name
-    key = property(key)
 
     def contribute_to_class(self, cls, attribute_name):
         self.module_name = cls.__module__
@@ -65,9 +62,10 @@ class Value(object):
 
         setattr(cls, self.attribute_name, self)
 
-    def __get__(self, instance=None, type=None):
-        if instance == None:
-            raise AttributeError, "%r is only accessible from %s instances." % (self.attribute_name, type.__name__)
+    def __get__(self, instance=None, cls=None):
+        if instance is None:
+            raise AttributeError("%r is only accessible from %s instances." %
+                                 (self.attribute_name, cls.__name__))
         try:
             storage = get_setting_storage(*self.key)
             return self.to_python(storage.value)
@@ -97,8 +95,10 @@ class Value(object):
 # VALUE TYPES #
 ###############
 
+
 class BooleanValue(Value):
     unitialized_value = False
+
     class field(forms.BooleanField):
 
         def __init__(self, *args, **kwargs):
@@ -112,12 +112,14 @@ class BooleanValue(Value):
 
     to_editor = to_python
 
+
 class DecimalValue(Value):
     field = forms.DecimalField
 
     def to_python(self, value):
         return Decimal(value)
 
+
 # DurationValue has a lot of duplication and ugliness because of issue #2443
 # Until DurationField is sorted out, this has to do some extra work
 class DurationValue(Value):
@@ -129,7 +131,8 @@ class DurationValue(Value):
             except (ValueError, TypeError):
                 raise forms.ValidationError('This value must be a real number.')
             except OverflowError:
-                raise forms.ValidationError('The maximum allowed value is %s' % datetime.timedelta.max)
+                raise forms.ValidationError('The maximum allowed value is %s' %
+                                            datetime.timedelta.max)
 
     def to_python(self, value):
         if isinstance(value, datetime.timedelta):
@@ -144,18 +147,21 @@ class DurationValue(Value):
     def get_db_prep_save(self, value):
         return unicode(value.days * 24 * 3600 + value.seconds + float(value.microseconds) / 1000000)
 
+
 class FloatValue(Value):
     field = forms.FloatField
 
     def to_python(self, value):
         return float(value)
 
+
 class IntegerValue(Value):
     field = forms.IntegerField
 
     def to_python(self, value):
         return int(value)
 
+
 class PercentValue(Value):
 
     class field(forms.DecimalField):
@@ -173,6 +179,7 @@ class PercentValue(Value):
     def to_python(self, value):
         return Decimal(value) / 100
 
+
 class PositiveIntegerValue(IntegerValue):
 
     class field(forms.IntegerField):
@@ -181,10 +188,12 @@ class PositiveIntegerValue(IntegerValue):
             kwargs['min_value'] = 0
             forms.IntegerField.__init__(self, *args, **kwargs)
 
+
 class StringValue(Value):
     unitialized_value = ''
     field = forms.CharField
 
+
 class TextValue(Value):
     unitialized_value = ''
     field = forms.CharField
@@ -192,6 +201,7 @@ class TextValue(Value):
     def to_python(self, value):
         return unicode(value)
 
+
 class EmailValue(Value):
     unitialized_value = ''
     field = forms.EmailField
@@ -199,6 +209,7 @@ class EmailValue(Value):
     def to_python(self, value):
         return unicode(value)
 
+
 class MultiSeparatorValue(TextValue):
     """Provides a way to store list-like string settings.
     e.g 'mail@test.com;*@blah.com' would be returned as
@@ -207,9 +218,10 @@ class MultiSeparatorValue(TextValue):
         separator string (default is semi-colon as above).
     """
 
-    def __init__(self, description=None, help_text=None, separator=';', required=True, default=None):
+    def __init__(self, description=None, help_text=None, separator=';', required=True,
+                 default=None):
         self.separator = separator
-        if default != None:
+        if default is not None:
             # convert from list to string
             default = separator.join(default)
         super(MultiSeparatorValue, self).__init__(description=description,
@@ -231,6 +243,7 @@ class MultiSeparatorValue(TextValue):
             value = []
         return value
 
+
 class ImageValue(Value):
     def __init__(self, *args, **kwargs):
         if 'upload_to' in kwargs:
@@ -240,8 +253,6 @@ class ImageValue(Value):
     class field(forms.ImageField):
         class widget(forms.FileInput):
             "Widget with preview"
-            def __init__(self, attrs={}):
-                forms.FileInput.__init__(self, attrs)
 
             def render(self, name, value, attrs=None):
                 output = []
@@ -251,9 +262,9 @@ class ImageValue(Value):
                         raise IOError('No value')
 
                     Image.open(value.file)
-                    file_name = pjoin(settings.MEDIA_URL, value.name).replace("\\","/")
-                    params = {"file_name" : file_name }
-                    output.append(u'<p><img src="%(file_name)s" width="100" /></p>' % params )
+                    file_name = pjoin(settings.MEDIA_URL, value.name).replace("\\", "/")
+                    params = {"file_name": file_name}
+                    output.append(u'<p><img src="%(file_name)s" width="100" /></p>' % params)
                 except IOError:
                     pass
 
